@@ -4,4 +4,4 @@
 UNUR_PAR *unur_dgt_new( const UNUR_DISTR *distribution );
 int unur_dgt_set_guidefactor( UNUR_PAR *parameters, double factor );
 int unur_dgt_set_variant( UNUR_PAR *parameters, unsigned variant );
-int unur_dgt_eval_invcdf( const UNUR_GEN *generator, double u );
+int unur_dgt_eval_invcdf( const UNUR_GEN *generator, double u, double *recycle );
