@@ -322,7 +322,7 @@ int unur_dau_set_urnfactor( UNUR_PAR *parameters, double factor );
 UNUR_PAR *unur_dgt_new( const UNUR_DISTR *distribution );
 int unur_dgt_set_guidefactor( UNUR_PAR *parameters, double factor );
 int unur_dgt_set_variant( UNUR_PAR *parameters, unsigned variant );
-int unur_dgt_eval_invcdf( const UNUR_GEN *generator, double u );
+int unur_dgt_eval_invcdf( const UNUR_GEN *generator, double u, double *recycle );
 UNUR_PAR *unur_dsrou_new( const UNUR_DISTR *distribution );
 int unur_dsrou_set_cdfatmode( UNUR_PAR *parameters, double Fmode );
 int unur_dsrou_set_verify( UNUR_PAR *parameters, int verify );
@@ -570,6 +570,9 @@ double _unur_cstd_sample_inv( struct unur_gen *gen );
 UNUR_PAR *unur_dstd_new( const UNUR_DISTR *distribution );
 int unur_dstd_set_variant( UNUR_PAR *parameters, unsigned variant );
 UNUR_PAR *unur_mvstd_new( const UNUR_DISTR *distribution );
+UNUR_PAR *unur_mixt_new( int n, const double *prob, UNUR_GEN **comp );
+int unur_mixt_set_useinversion( UNUR_PAR *parameters, int useinv );
+double unur_mixt_eval_invcdf( const UNUR_GEN *generator, double u );
 UNUR_PAR *unur_cext_new( const UNUR_DISTR *distribution );
 int unur_cext_set_init( UNUR_PAR *parameters, int (*init)(UNUR_GEN *gen) );
 int unur_cext_set_sample( UNUR_PAR *parameters, double (*sample)(UNUR_GEN *gen) );
